<?php
/*
Plugin Name: Daum Map Custom Meta
Description: 개별 글에서 다음 지도 삽입 여부와 주소를 설정할 수 있도록 합니다.
Version: 1.1
Author: 사용자
*/

// 1. 글 작성 화면에 "다음 지도 삽입" 및 "주소 입력" 필드 추가
function add_daum_map_meta_box() {
    add_meta_box(
        'daum_map_meta_box',
        '다음 지도 설정',
        'render_daum_map_meta_box',
        'post',
        'side',
        'high'
    );
}
add_action('add_meta_boxes', 'add_daum_map_meta_box');

// 2. 체크박스 및 주소 입력 필드 렌더링
function render_daum_map_meta_box($post) {
    $show_map = get_post_meta($post->ID, '_show_daum_map', true);
    $map_address = get_post_meta($post->ID, '_daum_map_address', true);
    
    wp_nonce_field('daum_map_meta_box_nonce', 'daum_map_meta_box_nonce');
    ?>
    <p>
        <label for="show_daum_map">
            <input type="checkbox" id="show_daum_map" name="show_daum_map" value="yes" <?php checked($show_map, 'yes'); ?>>
            이 글에 Daum 지도 삽입
        </label>
    </p>
    <p>
        <label for="daum_map_address">지도 주소:</label><br>
        <input type="text" id="daum_map_address" name="daum_map_address" value="<?php echo esc_attr($map_address); ?>" style="width: 100%;">
    </p>
    <?php
}

// 3. 입력된 값 저장
function save_daum_map_meta_box($post_id) {
    if (!isset($_POST['daum_map_meta_box_nonce']) || !wp_verify_nonce($_POST['daum_map_meta_box_nonce'], 'daum_map_meta_box_nonce')) {
        return;
    }

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    $show_map = isset($_POST['show_daum_map']) ? 'yes' : 'no';
    update_post_meta($post_id, '_show_daum_map', $show_map);

    if (isset($_POST['daum_map_address'])) {
        update_post_meta($post_id, '_daum_map_address', sanitize_text_field($_POST['daum_map_address']));
    }
}
add_action('save_post', 'save_daum_map_meta_box');

// 4. 본문 끝에 다음 지도 삽입 (체크된 경우 & 주소 입력된 경우만)
function add_daum_map_to_content($content) {
    if (is_single()) {
        $show_map = get_post_meta(get_the_ID(), '_show_daum_map', true);
        $map_address = get_post_meta(get_the_ID(), '_daum_map_address', true);

        if ($show_map === 'yes' && !empty($map_address)) {
            $encoded_address = urlencode($map_address);
            $map_iframe = '<iframe src="https://map.kakao.com/link/search/' . $encoded_address . '" width="100%" height="400" style="border:0;" allowfullscreen></iframe>';
            $content .= $map_iframe;
        }
    }
    return $content;
}
add_filter('the_content', 'add_daum_map_to_content');

?>
